# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Group Service."""

__version__ = "2.11.9"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .create_new_group_public_v1 import CreateNewGroupPublicV1
from .delete_group_admin_v1 import DeleteGroupAdminV1
from .delete_group_predefined_dbecca import DeleteGroupPredefinedRulePublicV1
from .delete_group_public_v1 import DeleteGroupPublicV1
from .get_group_list_admin_v1 import GetGroupListAdminV1
from .get_group_list_public_v1 import GetGroupListPublicV1
from .get_single_group_admin_v1 import GetSingleGroupAdminV1
from .get_single_group_public_v1 import GetSingleGroupPublicV1
from .update_group_custom_att_c48713 import UpdateGroupCustomAttributesPublicV1
from .update_group_custom_rul_0b1934 import UpdateGroupCustomRulePublicV1
from .update_group_predefined_94da96 import UpdateGroupPredefinedRulePublicV1
from .update_patch_single_gro_ce5ae8 import UpdatePatchSingleGroupPublicV1
from .update_single_group_v1 import UpdateSingleGroupV1
